**To list all repositories associated with a template**

The following ``list-repositories-for-approval-rule-template`` example lists all repositories associated with the specified approval rule template. ::

    aws codecommit list-repositories-for-approval-rule-template \
        --approval-rule-template-name 2-approver-rule-for-master

Output::

    {
        "repositoryNames": [
            "MyDemoRepo",
            "MyClonedRepo"
        ]
    }

For more information, see `Manage Approval Rule Templates <https://docs.aws.amazon.com/codecommit/latest/userguide/how-to-manage-templates.html#list-associated-repositories>`__ in the *AWS CodeCommit User Guide*.
